@@ -1,39 +1,28 @@
 /*
-==============================================================================
-        chadic.h
-                1990/12/06/Thu  Yutaka MYOKI(Nagao Lab., KUEE)
-                1990/01/09/Wed  Last Modified
-                                          >>> 94/02 changed by T.Nakamura <<<
-==============================================================================
-*/
+ * chadic.h
+ *     1990/12/06/Thu  Yutaka MYOKI(Nagao Lab., KUEE)
+ *
+ * $Id: chadic.h,v 1.18 2001/03/16 06:13:57 kazuma-t Exp $
+ */
+
 #ifndef __CHADIC_H__
 #define __CHADIC_H__
 
+#include "config.h"
+
 #include <stdio.h>
+#include <stdlib.h>
 #include <ctype.h>
 #include <string.h>
 #include <limits.h>
 
+#ifdef HAVE_UNISTD_H
 #include <sys/types.h>
-#include <sys/stat.h>
-#if defined _WIN32 && ! defined __CYGWIN__
-#include <io.h>
-#else
-#include <sys/file.h>
-#endif
-#include <time.h>
+#endif /* HAVE_UNISTD_H */
 
-#include <stdlib.h>
-#include <fcntl.h>
-
-#include "config.h"
 #include "pat.h"
 #include "sufary.h"
 
-/*
-grep * macros
- */
-
 #ifndef FALSE
 #define FALSE  ((int)0)
 #endif
@@ -48,13 +37,6 @@ grep * macros
 #define PATH_DELIMITER  '/'
 #endif
 
-/* fseek() */
-#ifndef SEEK_SET
-#define SEEK_SET  0
-#define SEEK_CUR  1
-#define SEEK_END  2
-#endif
-
 #define CHAINT_OFFSET   11
 #define CHAINT_SCALE    (256-CHAINT_OFFSET)
 
@@ -75,8 +57,9 @@ grep * macros
 #define ESTR_BOS_EOS         "BOS/EOS"
 
 /* cforms.cha */
-#define JSTR_BASIC_FORM  "ܷ"
-#define ESTR_BASIC_FORM  "BASIC"
+#define JSTR_BASE_FORM  "ܷ"
+#define ESTR_BASE_FORM1  "BASEFORM"
+#define ESTR_BASE_FORM2  "STEMFORM"
 
 /* *.dic */
 #define JSTR_DEF_POS_COST  "ǥեʻ쥳"
@@ -100,8 +83,8 @@ grep * macros
 #define JSTR_INFO1         "ղþ"
 #define JSTR_INFO2         "̣"
 #define ESTR_INFO          "INFO"
-#define JSTR_COMPO         "ʣ"
-#define ESTR_COMPO         "COMP"
+#define JSTR_COMPOUND      "ʣ"
+#define ESTR_COMPOUND      "COMPOUND"
 #define JSTR_SEG           ""
 #define ESTR_SEG           "SEG"
 #define JSTR_CONN_ATTR     "Ϣ°"
@@ -130,10 +113,10 @@ grep * macros
 #define ESTR_COST_WIDTH     "COST_WIDTH"
 #define JSTR_DEF_CONN_COST  "̤Ϣܥ"
 #define ESTR_DEF_CONN_COST  "DEF_CONN_COST"
-#define JSTR_COMPO_POS      "Ϣʻ"
-#define ESTR_COMPO_POS      "COMPOSIT_POS"
-#define JSTR_OUTPUT_COMPO   "ʣ"
-#define ESTR_OUTPUT_COMPO   "OUTPUT_COMPOUND"
+#define JSTR_COMPOSIT_POS      "Ϣʻ"
+#define ESTR_COMPOSIT_POS      "COMPOSIT_POS"
+#define JSTR_OUTPUT_COMPOUND   "ʣ"
+#define ESTR_OUTPUT_COMPOUND   "OUTPUT_COMPOUND"
 #define ESTR_PAT_FILE       "PATDIC" /* changed by Tatuo 960920 */
 #define ESTR_SUF_FILE       "SUFDIC"
 #define JSTR_OUTPUT_FORMAT  "ϥեޥå"
@@ -190,16 +173,16 @@ grep * macros
 #define strmatch2(s,s1,s2)      (!strcmp(s,s1)||!strcmp(s,s2))
 #define strmatch3(s,s1,s2,s3)   (!strcmp(s,s1)||!strcmp(s,s2)||!strcmp(s,s3))
 
+/*
+ * structures
+ */
+
 /* rensetu matrix */
 typedef struct _connect_rule_t {
     unsigned short next;
     unsigned short cost;
 } connect_rule_t;
 
-/*
- * structures
- */
-
 /* <cha_car>  <cha_cdr> ؤΥݥ󥿤ɽ줿 */
 typedef struct _bin_t {
     void *cha_car;			/* address of <cha_car> */
@@ -216,9 +199,6 @@ typedef struct _cell {
 } chasen_cell_t;
 
 /* this structure is used only in mkchadic */
-               /* changed by T.Nakamura and S.Kurohashi 
-                  ¤ mrph_t ٤Ƥξ 
-                  ¤ MORPHEME Ϥʤʤä */
 /* morpheme */
 typedef struct _mrph {
     char midasi[MIDASI_LEN];  /* surface form */
@@ -237,43 +217,43 @@ typedef struct _mrph {
     char is_undef;            /* the unseen word or not */
 } mrph_t;
 
-/* POS information */
+/* POS information -- see also the comments (the end of this file) */
 typedef struct _hinsi_t {
-    short *path;
-    short *daughter;
-    char  *name;
-    char  *bkugiri;
-    short comp; /* Ϣʻֹ */
-    char  depth;
-    char  kt;
+    short *path;         /* the path to top node */
+    short *daughter;     /* the daughter node */
+    char  *name;         /* the name of POS (at the level) */
+    char  *bkugiri;      /* for bunsetsu segmentation */
+    short composit;      /* for the COMPOSIT_POS */ 
+    char  depth;         /* the depth from top node */
+    char  kt;            /* have conjugation or not */
     unsigned char cost;
 } hinsi_t;
 
 /* ѷ conjugation type */
 typedef struct _ktype {
-    char   *name;
-    short  basic;
+    char   *name;    /* CTYPE name */
+    short  basic;    /* base form */
 } ktype_t;
 
 /* ѷ conjugation form */
 typedef struct _kform {
-    char  *name;
-    char  *gobi;
-    int   gobi_len;
-    char  *ygobi;
-    char  *pgobi;
+    char  *name;     /* CFORM name */
+    char  *gobi;     /* suffix of surface form */
+    int   gobi_len;  /* the length of suffix */
+    char  *ygobi;    /* suffix of Japanese reading */
+    char  *pgobi;    /* suffix of Japanese pronunciation */
 } kform_t;
 
 /* Ϣɽ connection matrix */
 typedef struct _rensetu_pair {
     short  index;
-    short  i_pos;
-    short  j_pos;
+    short  i_pos;  /* the POS index in the current state (= preceding morpheme) */  
+    short  j_pos;  /* the POS index in the input (= current morpheme) */
 
-    unsigned short hinsi;
-    unsigned char type;
-    unsigned char form;
-    char   *goi;
+    unsigned short hinsi;   /* POS */
+    unsigned char type;     /* CTYPE */
+    unsigned char form;     /* CFORM */
+    char   *goi;   /* Lexicalized POS */
 } rensetu_pair_t;
 
 /*
@@ -281,7 +261,7 @@ typedef struct _rensetu_pair {
  */
 
 #define HINSI_MAX     4096
-extern hinsi_t Cha_hinsi[HINSI_MAX];
+extern hinsi_t Cha_hinsi[HINSI_MAX];  /* see also the comments (the end of this file) */
 extern ktype_t Cha_type[TYPE_NUM];
 extern kform_t Cha_form[TYPE_NUM][FORM_NUM];
 extern int Cha_lineno, Cha_lineno_error;
@@ -380,6 +360,39 @@ int cha_getopt_chasen(char**, FILE*);
 
 /* mmap.c */
 off_t cha_mmap_file(char*, void**);
+off_t cha_mmap_file_w(char*, void**);
 void cha_munmap_file(void*, off_t);
 
 #endif /* __CHADIC_H__ */
+
+
+/*
+  the data format of the structure hinsi_t
+  the POS informations are treated in global valuable Cha_hinsi[n]
+
+=============                          ===================
+"grammar.cha"                          "real POS tag list"
+=============                          ===================
+(A1                   ; Cha_hinsi[1]
+    (B1)              ; Cha_hinsi[2]   A1-B1                 ; Cha_hinsi[2]
+    (B2               ; Cha_hinsi[3]
+	(C1)          ; Cha_hinsi[4]   A1-B2-C1              ; Cha_hinsi[4]
+	(C2           ; Cha_hinsi[5]
+	    (D1)      ; Cha_hinsi[6]   A1-B2-C2-D1           ; Cha_hinsi[6]
+	    (D2)      ; Cha_hinsi[7]   A1-B2-C2-D2           ; Cha_hinsi[7]
+	    (D3))     ; Cha_hinsi[8]   A1-B2-C2-D3           ; Cha_hinsi[8]
+	(C3)          ; Cha_hinsi[9]   A1-B2-C3              ; Cha_hinsi[9]
+	(C4           ; Cha_hinsi[10]
+	    (D4)      ; Cha_hinsi[11]  A1-B2-C4-D4           ; Cha_hinsi[11]
+	    (D5))))   ; Cha_hinsi[12]  A1-B2-C4-D5           ; Cha_hinsi[12]
+
+=========================================
+*hinsi_t Cha_hinsi[HINSI] for the example
+=========================================
+n (idx)                =  1  2  3  4  5  6  7  8  9  10 11 12
+Cha_hinsi[n].name      =  A1 B1 B2 C1 C2 D1 D2 D3 C3 C4 D4 D5
+Cha_hinsi[n].depth     =  1  2  2  3  3  4  4  4  3  3  4  4
+*Cha_hinsi[n].daughter =  2  0  4  0  6  0  0  0  0  11 0  0
+*Cha_hinsi[n].path     =  1  1  1  1  1  1  1  1  1  1  1  1
+
+*/
