@@ -37,11 +37,16 @@
  * 1990/12/14/Fri       Yutaka MYOKI(Nagao Lab., KUEE)
  * 1990/12/25/Tue       Modified
  * Oct. 1996       A.Kitauchi <akira-k@is.aist-nara.ac.jp>
- * $Id: iotool.c,v 1.11 2001/02/24 06:17:22 kazuma-t Exp $
+ * $Id: iotool.c,v 1.11.4.1 2001/06/24 06:19:02 taku-ku Exp $
  */
 #include <stdio.h>
 #include <stdarg.h>
 #include "chadic.h"
+#include "config.h"
+
+#ifdef HAVE_WINDOWS_H
+#include <windows.h>
+#endif
 
 #ifdef PATHTYPE_MSDOS
 #define RCFILE "\\chasenrc"
@@ -514,6 +519,7 @@ cha_fopen_rcfile(void)
 	if ((fp = cha_fopen(chasenrc_path, "r", -1)) != NULL)
 	    return fp;
     }
+    /*
     strcpy(chasenrc_path, progpath);
     sprintf(strrchr(chasenrc_path, PATH_DELIMITER) + 1, "dic%s", RC2FILE);
     if ((fp = cha_fopen(chasenrc_path, "r", -1)) != NULL)
@@ -521,13 +527,20 @@ cha_fopen_rcfile(void)
     strcpy(chasenrc_path, progpath);
     sprintf(strrchr(chasenrc_path, PATH_DELIMITER) + 1, "dic%s", RCFILE);
     if ((fp = cha_fopen(chasenrc_path, "r", -1)) != NULL)
-	return fp;
+    return fp; 
+    */
 #endif /* PATHTYPE_MSDOS */
 
     /*
      * RCPATH in rcpath.h 
      */
+#if defined HAVE_WINDOWS_H && defined _WIN32
+    GetPrivateProfileString("chasenrc", "chasenrc", RCPATH,
+                          chasenrc_path, sizeof(chasenrc_path), "chasen.ini");
+#else
     strcpy(chasenrc_path, RCPATH);
+#endif
+
     if ((fp = cha_fopen(chasenrc_path, "r", -1)) != NULL)
 	return fp;
 
