@@ -1,5 +1,5 @@
 /*
- * $Id: tokenizer.h,v 1.4 2001/03/10 02:02:43 kazuma-t Exp $
+ * $Id: tokenizer.h,v 1.4.6.1 2001/06/21 05:37:36 masayu-a Exp $
  */
 
 #ifndef __TOKENIZER_H__
@@ -15,7 +15,7 @@ enum cha_lang {
 
 /* for encoding scheme */
 enum cha_encode {
-    CHASEN_ENCODE_EUC,
+    CHASEN_ENCODE_EUCJP,
     CHASEN_ENCODE_ISO8859,
     CHASEN_ENCODE_UTF8
 };
