@@ -4,7 +4,7 @@
  * Υץθϡ NLPRS '95 Invited Lecture Kenneth W. Church
  * ΤΤѤޤ 
  *
- * $Id: mkary.c,v 1.9 2001/03/16 06:13:57 kazuma-t Exp $
+ * $Id: mkary.c,v 1.9.4.1 2001/06/24 06:19:02 taku-ku Exp $
  */
 
 #include "config.h"
@@ -180,7 +180,7 @@ sort_array_file(char *ary_fname, long pointer_cnt)
     message("Saving...\n");
 
 #ifndef HAVE_MMAP
-    dump_file(ary_fname, buf, pointer_cnt);
+    dump_file(ary_fname, suf, pointer_cnt);
 #endif
 }
 
